@@ -1,6 +1,6 @@
 package Pcore::PSGI::Controller;
 
-use Pcore qw[-role];
+use Pcore -role;
 use Pcore::Util::UA::Response;
 
 requires qw[run];
