@@ -107,16 +107,10 @@ sub call ( $self, $path, @args ) {
     if ( $path =~ /\Ahttp/sm ) {
         my $method = shift // 'GET';
 
-        P->http->request(
+        $res = P->http->_request(
             @args,
-            method    => $method,
-            url       => $path,
-            blocking  => 1,
-            on_finish => sub {
-                $res = $_[0];
-
-                return;
-            }
+            method => $method,
+            url    => $path,
         );
     }
     else {    # path MUST be the absolute controller path as string
@@ -188,6 +182,16 @@ sub is_exists {
 }
 
 1;
+## -----SOURCE FILTER LOG BEGIN-----
+##
+## PerlCritic profile "pcore-script" policy violations:
+## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
+## │ Sev. │ Lines                │ Policy                                                                                                         │
+## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
+## │    3 │ 110                  │ Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               │
+## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
+##
+## -----SOURCE FILTER LOG END-----
 __END__
 =pod
 
